# clear R
rm(list=ls())

# load required packages
library(readr)
library(ggplot2)
library(tidyverse)
library(scales)
library(lmerTest)
library(lattice)
library(rptR)
library(ggeffects)
library(lmtest)
library(piecewiseSEM)
library(survival)
library(survminer)
library(coxme)


###############################################################################################
#FIGURES AND STATS FOR SPECIFIC DYNAMIC ACTION (SDA) TRIALS FOR KRISTINEBERG WRASSE EXPERIMENT
###############################################################################################

# read the data
WRASSE <- read_delim("Wrasse_SDA_data.csv", delim=";", locale=locale(decimal_mark = "."), col_types = NULL, col_names=T)

# inspect data
head(WRASSE)

# change Fish ID to factor
WRASSE$Fish <- as.factor(WRASSE$Fish)

# rename columns for convenience
names(WRASSE) = c("Date","Fish","Mass","SMR_wholeanim","MMR_wholeanim","AS_wholeanim","worms_eaten","Mealsize_percentBM","PeakNetSDA_wholeanim","TimeToPeakSDA","SDAduration","SDAmagnitude_wholeanim")

# inspect data after renaming
head(WRASSE)



### SDA MAGNITUDE

# check for body mass effect on SDA magnitude
mod0.SDAmagnitude <- lm(log10(SDAmagnitude_wholeanim) ~ log10(Mass), data = WRASSE)
summary(mod0.SDAmagnitude)

# no body mass effect so mass-specific data (mg O2/g) calculated and used for plotting
WRASSE$SDAmagnitude_massspec <- WRASSE$SDAmagnitude_wholeanim/WRASSE$Mass

# plot of SDA magnitude
ggplot(WRASSE, aes(y=SDAmagnitude_massspec, x=Mealsize_percentBM, colour=Date))+
  geom_smooth(method=lm, se=T, colour="black")+
  geom_point(size=3, colour="black")+
  theme_bw()+
  theme(plot.background = element_blank(),
        panel.background = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank())+
  theme(panel.border = element_rect(color="black", size = 0.3))+
  theme(axis.line.x = element_blank(),
        axis.line.y = element_blank())+
  theme(legend.position=c(0,1), legend.justification=c(0,1), legend.title=element_text("Date"), legend.key = element_blank(), legend.background=element_blank())+
  theme(axis.ticks.length=unit(2,"mm"), axis.ticks.y = element_line(colour = "black", size = 0.3), axis.ticks.x = element_line(colour = "black", size = 0.3))+
  theme(aspect.ratio=1/1)+
  theme(text = element_text(size=14, colour="black"),
        axis.text.y = element_text(size=14, colour="black"), 
        axis.text.x = element_text(size=14, colour="black"))+
  scale_x_continuous(breaks=seq(0,9,1))+
  scale_y_continuous(breaks=seq(0,3.5,0.5))+
  coord_cartesian(xlim=c(0,9), ylim=c(-0.2,3.7))+
  labs(y=expression(SDA ~ magnitude ~ (mg ~ O[2] ~ g ~ fish^-1)), x=expression(Meal ~ size ~ ("%" ~ of ~ body ~ mass)))

# model of SDA magnitude
mod1.SDAmagnitude <- lm(SDAmagnitude_wholeanim ~ Mealsize_percentBM * Mass, data=WRASSE)
summary(mod1.SDAmagnitude)

# interaction between meal size and body mass non-significant, so model reduced by removing interaction
mod2.SDAmagnitude <- lm(SDAmagnitude_wholeanim ~ Mealsize_percentBM + Mass, data=WRASSE)
anova(mod1.SDAmagnitude, mod2.SDAmagnitude)
summary(mod2.SDAmagnitude)
anova(mod2.SDAmagnitude)
# borderline effect of body mass (p = 0.096), so mass left in final model

# model diagnostics
plot(mod2.SDAmagnitude)
hist(mod2.SDAmagnitude$residuals)



### PEAK SDA

# calculate peak MO2 during SDA as % of AS
WRASSE$PeakSDA_percentAS <- (WRASSE$PeakNetSDA_wholeanim/WRASSE$AS_wholeanim)*100

# plot of peak SDA
ggplot(WRASSE, aes(y=PeakSDA_percentAS, x=Mealsize_percentBM))+
  geom_smooth(method=lm, se=T, colour="black")+
  geom_point(size=3, colour="black")+
  theme_bw()+
  theme(plot.background = element_blank(),
        panel.background = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank())+
  theme(panel.border = element_rect(color="black", size = 0.3))+
  theme(axis.line.x = element_blank(),
        axis.line.y = element_blank())+
  theme(legend.position=c(0,1), legend.justification=c(0,1), legend.title=element_text("Date"), legend.key = element_blank(), legend.background=element_blank())+
  theme(axis.ticks.length=unit(2,"mm"), axis.ticks.y = element_line(colour = "black", size = 0.3), axis.ticks.x = element_line(colour = "black", size = 0.3))+
  theme(aspect.ratio=1/1)+
  theme(text = element_text(size=14, colour="black"),
        axis.text.y = element_text(size=14, colour="black"), 
        axis.text.x = element_text(size=14, colour="black"))+
  scale_x_continuous(breaks=seq(0,9,1))+
  scale_y_continuous(breaks=seq(0,50,10))+
  coord_cartesian(xlim=c(0,9), ylim=c(0,50))+
  labs(y=expression(MO[2] ~ at ~ peak ~ SDA ~ ("%" ~ of ~ aerobic ~ scope)), x=expression(Meal ~ size ~ ("%" ~ of ~ body ~ mass)))

# model with peak SDA as % of AS
mod1.PeakSDA <- lm(PeakSDA_percentAS ~ Mealsize_percentBM * Mass, data=WRASSE)
summary(mod1.PeakSDA)

# interaction between meal size and body mass non-significant, so model reduced by removing interaction
mod2.PeakSDA <- lm(PeakSDA_percentAS ~ Mealsize_percentBM + Mass, data=WRASSE)
anova(mod1.PeakSDA, mod2.PeakSDA)
summary(mod2.PeakSDA)

# additional model reduction (body mass removed)
mod3.PeakSDA <- lm(PeakSDA_percentAS ~ Mealsize_percentBM, data=WRASSE)
anova(mod2.PeakSDA, mod3.PeakSDA)
summary(mod3.PeakSDA)
anova(mod3.PeakSDA)

# model diagnostics
plot(mod3.PeakSDA)
hist(mod3.PeakSDA$residuals)

# predicted peak SDA (percent of AS) eaten for a 4.2 g fish (mean body mass in behavioural experiments)
predictPeakSDA_percentAS <- ggpredict(mod3.PeakSDA, terms=c("Mealsize_percentBM"), condition=c(Mass=4.2))
predictPeakSDA_percentAS

# get model coefficients for calculation of average percent AS occupied during digestion in fish from behavioural experiments
mod.PeakSDA.predict <- lm(predicted ~ x, data=predictPeakSDA_percentAS)
summary(mod.PeakSDA.predict)



################################################################################################
#FIGURES AND STATS FOR HOLDING TANK TRIALS FOR KRISTINEBERG WRASSE PREDATOR EXPOSURE EXPERIMENT
################################################################################################

# NOTES: 
# Predator = wrasses have been kept with a predator (cod) in their holding tanks
# No predator = wrasses have not been kept with a predator in their holding tanks
# Fish 6, 15, and 17 exhibited abnormal behaviour (swimming at the surface) when transferred to the behavioural arenas for the next set of experiments (analyses further below), and they were therefore removed from those trials. The abnormal behaviour was not observed in the holding tanks and data diagnostics below do not identify them as consistent outliers in these holding tank data. The fish were therefore retained in the analyses of the holding tank data.


### FOOD (BLOODWORM) CONSUMPTION

# read the data
WrasseFeeding <- read_delim("Wrasse_food_consumption_in_holding_tanks_data.csv", delim=";", locale=locale(decimal_mark = "."), col_types = NULL, col_names=T)

# inspect data
head(WrasseFeeding)

# data wrangling
WrasseFeeding$Holding_tank <- as.factor(WrasseFeeding$Holding_tank)
WrasseFeeding$FishID <- as.factor(WrasseFeeding$FishID)

# remove number of worms eaten at 3 h, as this time point was recorded inconsistently on only some days
WrasseFeeding <- subset(WrasseFeeding, Hours_since_feeding >= 16)

# more data wrangling
WrasseFeeding_Total<- WrasseFeeding %>%
  group_by(Date,FishID) %>%
  mutate(Consumption_Total=sum(Consumption))%>%
  distinct(Date,FishID,.keep_all=T)
WrasseFeeding_Total <- WrasseFeeding_Total %>% drop_na(Consumption_Total)

# add food consumption in % of body mass (wet weight of one worm was 7.144 mg)
WrasseFeeding_Total$Consumption_percentBM <- ((WrasseFeeding_Total$Consumption_Total * (7.144/1000))/WrasseFeeding_Total$BodyMass_g_calculated)*100

# Plot of total food consumption as number of bloodworms eaten per day
ggplot(data = WrasseFeeding_Total, aes(Day, Consumption_Total, colour=Treatment, shape=Treatment, fill=Treatment))+
  scale_color_manual(values=c("dodgerblue4", "coral3"))+
  scale_fill_manual(values=c("dodgerblue4", "coral3"))+
  scale_shape_manual(values=c(16,18))+
  stat_summary(fun=sum, geom="line", aes(group=FishID), alpha=0.2)+
  geom_point(alpha=0.3,size=2.5)+
  geom_smooth(method="lm", alpha=0.2)+
  theme_bw()+
  theme(plot.background = element_blank(),
        panel.background = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank())+
  theme(panel.border = element_rect(color="black", size = 0.3))+
  theme(axis.line.x = element_blank(),
        axis.line.y = element_blank())+
  theme(axis.ticks.length=unit(2,"mm"), axis.ticks.y = element_line(colour = "black", size = 0.3), axis.ticks.x = element_line(colour = "black", size = 0.3))+
  theme(aspect.ratio=1/2)+
  theme(text = element_text(size=14, colour="black"),
        axis.text.y = element_text(size=14, colour="black"), 
        axis.text.x = element_text(size=14, colour="black"))+
  scale_x_continuous(breaks=seq(1,11,1))+
  scale_y_continuous(breaks=seq(0,80,10))+
  coord_cartesian(xlim=c(1,11), ylim=c(0,80))+
  labs(y=expression(Food ~ consumption ~ ("#" ~ of ~ bloodworms)), x=expression(Day))

# Plot of total food consumption as percent of fish body mass per day
ggplot(data = WrasseFeeding_Total, aes(Day, Consumption_percentBM, colour=Treatment, shape=Treatment, fill=Treatment))+
  scale_color_manual(values=c("dodgerblue4", "coral3"))+
  scale_fill_manual(values=c("dodgerblue4", "coral3"))+
  scale_shape_manual(values=c(16,18))+
  stat_summary(fun=sum, geom="line", aes(group=FishID), alpha=0.2)+
  geom_point(alpha=0.3,size=2.5)+
  geom_smooth(method="lm", alpha=0.2)+
  theme_bw()+
  theme(plot.background = element_blank(),
        panel.background = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank())+
  theme(panel.border = element_rect(color="black", size = 0.3))+
  theme(axis.line.x = element_blank(),
        axis.line.y = element_blank())+
  theme(axis.ticks.length=unit(2,"mm"), axis.ticks.y = element_line(colour = "black", size = 0.3), axis.ticks.x = element_line(colour = "black", size = 0.3))+
  theme(aspect.ratio=1/2)+
  theme(text = element_text(size=14, colour="black"),
        axis.text.y = element_text(size=14, colour="black"), 
        axis.text.x = element_text(size=14, colour="black"))+
  scale_x_continuous(breaks=seq(1,11,1))+
  scale_y_continuous(breaks=seq(0,15,3))+
  coord_cartesian(xlim=c(1,11), ylim=c(0,15))+
  labs(y=expression(Food ~ consumption ~ ("%" ~ of ~ body ~ mass)), x=expression(Day))

# plot with food consumption of individual fish on individual days (data points) to inspect if surface-swimming fish (fish 6, 15 & 17) stand out as outliers (see notes above)
ggplot(WrasseFeeding_Total, aes(FishID, Consumption_percentBM, color=Treatment))+
  geom_jitter(width=0.1, height=0)+
  scale_color_manual(values=c("dodgerblue4", "coral3"))+
  labs(y=expression(Food ~ consumption ~ ("%" ~ of ~ body ~ mass)), x=expression(Fish))+
  geom_rect(aes(xmin=5.5,xmax=6.5,ymin=-0.2,ymax=15), linetype="dashed", fill=NA, colour="grey70", size=0.5)+
  geom_rect(aes(xmin=14.5,xmax=15.5,ymin=-0.2,ymax=15), linetype="dashed", fill=NA, colour="grey70", size=0.5)+
  geom_rect(aes(xmin=16.5,xmax=17.5,ymin=-0.2,ymax=15), linetype="dashed", fill=NA, colour="grey70", size=0.5)
# they do not appear to stand out (also see model diagnostics below)


# model with food intake as number of bloodworms eaten
Feeding_mod1 <- lmer(Consumption_Total ~ Treatment * Day + BodyMass_g_calculated + (1|Holding_tank/FishID), data=WrasseFeeding_Total, na.action = na.omit, REML = T)
summary(Feeding_mod1)

# model reduction (non-significant interaction removed)
Feeding_mod1.2 <- lmer(Consumption_Total ~ Treatment + Day + BodyMass_g_calculated + (1|Holding_tank/FishID), data=WrasseFeeding_Total, na.action = na.omit, REML = T)
anova(Feeding_mod1, Feeding_mod1.2)
summary(Feeding_mod1.2)
# model failed to converge so holding tank removed next as random effect, as variance explained is near zero

# model reduction
Feeding_mod1.3 <- lmer(Consumption_Total ~ Treatment * Day + BodyMass_g_calculated + (1|FishID), data=WrasseFeeding_Total, na.action = na.omit, REML = T)
anova(Feeding_mod1, Feeding_mod1.3)
summary(Feeding_mod1.3)

# model reduction (non-significant interaction removed)
Feeding_mod1.4 <- lmer(Consumption_Total ~ Treatment + Day + BodyMass_g_calculated + (1|FishID), data=WrasseFeeding_Total, na.action = na.omit, REML = T)
anova(Feeding_mod1.3, Feeding_mod1.4)
summary(Feeding_mod1.4)
rsquared(Feeding_mod1.4)
# no further model reduction, as body mass and day are both borderline significant
# no treatment effect

# model diagnostics
plot(Feeding_mod1.4)
qqmath(Feeding_mod1.4, id=0.05, idLabels=~FishID)
ggplot(fortify.merMod(Feeding_mod1.4), aes(FishID,.resid)) + geom_boxplot() + coord_flip()
# fish 6 is flagged as a potential outlier, but no evidence for fish 15 or 17 being outliers
hist(resid(Feeding_mod1.4))

# predicted number of worms eaten for an average-sized (4.2 g) fish
predConsumption <- ggpredict(Feeding_mod1.4, terms=c("Day", "Treatment"), condition=c(BodyMass_g_calculated=(mean(WrasseFeeding_Total$BodyMass_g_calculated))))
predConsumption


# model with food intake as percent of fish body mass
Feeding_mod2 <- lmer(Consumption_percentBM ~ Treatment * Day + BodyMass_g_calculated + (1|Holding_tank/FishID), data=WrasseFeeding_Total, na.action = na.omit, REML = T)
summary(Feeding_mod2)

# model reduction (non-significant interaction removed)
Feeding_mod2.2 <- lmer(Consumption_percentBM ~ Treatment + Day + BodyMass_g_calculated + (1|Holding_tank/FishID), data=WrasseFeeding_Total, na.action = na.omit, REML = T)
anova(Feeding_mod2, Feeding_mod2.2)
summary(Feeding_mod2.2)

# model reduction 
Feeding_mod2.3 <- lmer(Consumption_percentBM ~ Treatment * Day + BodyMass_g_calculated + (1|FishID), data=WrasseFeeding_Total, na.action = na.omit, REML = T)
anova(Feeding_mod2, Feeding_mod2.3)
summary(Feeding_mod2.3)

# model reduction (non-significant interaction removed)
Feeding_mod2.4 <- lmer(Consumption_percentBM ~ Treatment + Day + BodyMass_g_calculated + (1|FishID), data=WrasseFeeding_Total, na.action = na.omit, REML = T)
anova(Feeding_mod2.3, Feeding_mod2.4)
summary(Feeding_mod2.4)

# model reduction
Feeding_mod2.5 <- lmer(Consumption_percentBM ~ Treatment + Day + (1|FishID), data=WrasseFeeding_Total, na.action = na.omit, REML = T)
anova(Feeding_mod2.4, Feeding_mod2.5)
summary(Feeding_mod2.5)
rsquared(Feeding_mod2.5)
# no treatment effect

# model diagnostics
plot(Feeding_mod2.5)
qqmath(Feeding_mod2.5, id=0.05, idLabels=~FishID)
ggplot(fortify.merMod(Feeding_mod2.5), aes(FishID,.resid)) + geom_boxplot() + coord_flip()
# fish 6 is flagged as a potential outlier, but no evidence for fish 15 or 17 being outliers
hist(resid(Feeding_mod2.5))

# predicted amount of worms (percent of body mass) eaten for an average-sized (4.2 g) fish
predConsumption_percentBM <- ggpredict(Feeding_mod2.4, terms=c("Day", "Treatment"), condition=c(BodyMass_g_calculated=(mean(WrasseFeeding_Total$BodyMass_g_calculated))))
predConsumption_percentBM

# Mean percentage of aerobic scope occupied by eaten food
# Predator present
coef(summary(mod.PeakSDA.predict))[1] + predConsumption_percentBM[2,2]*coef(summary(mod.PeakSDA.predict))[2]

# Predator absent
coef(summary(mod.PeakSDA.predict))[1] + predConsumption_percentBM[1,2]*coef(summary(mod.PeakSDA.predict))[2]



### CONSISTENCY (REPEATABILITY) OF FOOD CONSUMPTION

# calculate adjusted repeatability of food consumption (Radj)
rep_overall <- rpt(Consumption_percentBM ~ Treatment + Day + (1|FishID), grname = "FishID", data=WrasseFeeding_Total, datatype = "Gaussian", nboot = 1000, npermut = 0)
print(rep_overall)

# calculate repeatability for each treatment (predator vs. no predator) separately
WrasseFeeding_Total_Pred <- subset(WrasseFeeding_Total, Treatment == "Predator")
WrasseFeeding_Total_NoPred <- subset(WrasseFeeding_Total, Treatment == "No predator")

repPred <- rpt(Consumption_percentBM ~ Day + (1|FishID), grname = "FishID", data=WrasseFeeding_Total_Pred, datatype = "Gaussian", nboot = 1000, npermut = 0)
print(repPred)

repNoPred <- rpt(Consumption_percentBM ~ Day + (1|FishID), grname = "FishID", data=WrasseFeeding_Total_NoPred, datatype = "Gaussian", nboot = 1000, npermut = 0)
print(repNoPred)



### SPECIFIC GROWTH RATE (SGR)

# read the data
GrowthWrasse <- read_delim("Wrasse_growth_in_holding_tanks_data.csv", delim=";", locale=locale(decimal_mark = "."), col_types = cols(SGR = col_number(), MeanGramsPerDay = col_number(), TotalWormsEaten = col_number()))

# inspect data
head(GrowthWrasse)

# data wrangling
GrowthWrasse$Aquarium <- as.factor(GrowthWrasse$Aquarium)

# Plot of specific growth rate (% per day) as a function of the total number of bloodworms consumed
ggplot(GrowthWrasse, aes(x=MeanWormsPerDay, y=SGR, color=Treatment, shape=Treatment, fill=Treatment)) + 
  scale_color_manual(values = c("dodgerblue4", "coral3"))+
  scale_fill_manual(values=c("dodgerblue4", "coral3"))+
  scale_shape_manual(values=c(16,18))+
  geom_smooth(method="lm", se=T, size=1, alpha=0.2)+
  geom_point(size=3)+
  theme_bw()+
  theme(plot.background = element_blank(),
        panel.background = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank())+
  theme(panel.border = element_rect(color="black", size = 0.3))+
  theme(axis.line.x = element_blank(),
        axis.line.y = element_blank())+
  theme(axis.ticks.length=unit(2,"mm"), axis.ticks.y = element_line(colour = "black", size = 0.3), axis.ticks.x = element_line(colour = "black", size = 0.3))+
  theme(aspect.ratio=1/1)+
  theme(text = element_text(size=14, colour="black"),
        axis.text.y = element_text(size=14, colour="black"), 
        axis.text.x = element_text(size=14, colour="black"))+
  scale_x_continuous(breaks=seq(0,60,10))+
  scale_y_continuous(breaks=seq(-1.5,2,0.5))+
  coord_cartesian(xlim=c(0,60), ylim=c(-1.5,2))+
  labs(y=expression(Specific ~ growth ~ rate ~ ("%" ~ day^-1)), x=expression(Mean ~ daily ~ food ~ consumption ~ ("#" ~ of ~ bloodworms)))

# Plot of specific growth rate (% per day) as a function of bloodworms consumed in percent of mean fish body mass
ggplot(GrowthWrasse, aes(x=MeanDailyFoodIntake_percentBM, y=SGR, color=Treatment, shape=Treatment, fill=Treatment)) + 
  scale_color_manual(values = c("dodgerblue4", "coral3"))+
  scale_fill_manual(values=c("dodgerblue4", "coral3"))+
  scale_shape_manual(values=c(16,18))+
  geom_smooth(method="lm", se=T, size=1, alpha=0.2)+
  geom_point(size=3)+
  theme_bw()+
  theme(plot.background = element_blank(),
        panel.background = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank())+
  theme(panel.border = element_rect(color="black", size = 0.3))+
  theme(axis.line.x = element_blank(),
        axis.line.y = element_blank())+
  theme(axis.ticks.length=unit(2,"mm"), axis.ticks.y = element_line(colour = "black", size = 0.3), axis.ticks.x = element_line(colour = "black", size = 0.3))+
  theme(aspect.ratio=1/1)+
  theme(text = element_text(size=14, colour="black"),
        axis.text.y = element_text(size=14, colour="black"), 
        axis.text.x = element_text(size=14, colour="black"))+
  scale_x_continuous(breaks=seq(0,8,1))+
  scale_y_continuous(breaks=seq(-2,1.5,0.5))+
  coord_cartesian(xlim=c(0,8), ylim=c(-2,1.5))+
  labs(y=expression(Specific ~ growth ~ rate ~ ("%" ~ day^-1)), x=expression(Mean ~ daily ~ food ~ consumption ~ ("%" ~ of ~ mean ~ body ~ mass)))


# model for specific growth rate (SGR)
modSGR1 <- lmer(SGR ~ Treatment*MeanDailyFoodIntake_percentBM+MeanBodyMass+(1|Aquarium), data = GrowthWrasse, na.action = na.omit, REML = T)
summary(modSGR1)

# model reduction (non-significant interaction removed)
modSGR1.2 <- lmer(SGR ~ Treatment+MeanDailyFoodIntake_percentBM+MeanBodyMass+(1|Aquarium), data = GrowthWrasse, na.action = na.omit, REML = T)
anova(modSGR1, modSGR1.2)
summary(modSGR1.2)
# no treatment effect

# model diagnostics
plot(modSGR1.2)
# model with Fish as fixed effect for labeling QQ-plot with Fish ID
modSGRlabel <- lmer(SGR ~ Treatment+MeanDailyFoodIntake_percentBM+MeanBodyMass+Fish+(1|Aquarium), data=GrowthWrasse,na.action=na.omit,REML=T)
qqmath(modSGRlabel, id=0.05, idLabel=~Fish)
# fish 6 flagged as potential outlier in growth data, but fish 6 had normal food intake (see plot above)
hist(resid(modSGR1.2))



### TIME IN SHELTER

# NOTES:
# Time spent in shelter in holding tanks was checked 3 or 4 times a day
# Yes (1) = in shelter; No (0) = not in shelter

# read the data
Shelter.df <- read_delim("Wrasse_sheltering_in_holding_tank_data.csv", delim=";", locale=locale(decimal_mark = "."))

# inspect data
head(Shelter.df)

# data wrangling
Shelter.df$Holding_tank <- as.factor(Shelter.df$Holding_tank)
Shelter.df$FishID <- as.factor(Shelter.df$FishID)

# more data wrangling; grouping day and fishID
Shelter.df$DayFishID <- paste(Shelter.df$Day, Shelter.df$FishID)

# calculating percentage time spent in shelter each day
Shelternew.df <- Shelter.df %>%
  group_by(DayFishID)%>% 
  mutate(shelterpercent = mean(Shelter_num)*100)%>% 
  distinct(DayFishID, .keep_all=TRUE)

# exclude 24-27 June where fish were disturbed, as they were being caught and used in behavioural arena trials from the 24th
Shelternew.df2 <- subset(Shelternew.df, Day < 12)

# plot of time in shelter over duration of experiment
ggplot(Shelternew.df2, aes(Day, shelterpercent, color=Treatment)) + geom_jitter(width=0.2, height=1.5,alpha=0.3) + 
  stat_summary(fun = mean, geom = "point", size=3) + 
  scale_fill_brewer(palette="Pastel1") +
  scale_color_manual(values=c("coral3","dodgerblue4"))+
  theme_bw()+theme(legend.position="right")+ 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) + 
  theme(axis.text.y=element_text(size=12)) + 
  ylab("Time in shelter (%)") +
  geom_smooth(method="lm", formula=y~poly(x,1), se=F, size=1.5, aes(group=Treatment)) + 
  theme(axis.text.x=element_text(size=12), axis.title.y=element_text(size=15), plot.title=element_text(hjust=0.5, size=20))

# plot with sheltering of individual fish on individual days (data points) to inspect if surface-swimming fish (fish 6, 15 & 17) stand out as outliers (see notes above)
ggplot(Shelternew.df2, aes(FishID, shelterpercent, color=Treatment))+
  geom_jitter(width=0.2, height=1.5)+
  scale_color_manual(values=c("dodgerblue4", "coral3"))+
  labs(y=expression(Time~"in"~shelter~("%")), x=expression(Fish))+
  geom_rect(aes(xmin=5.5,xmax=6.5,ymin=-5,ymax=105), linetype="dashed", fill=NA, colour="grey70", size=0.5)+
  geom_rect(aes(xmin=14.5,xmax=15.5,ymin=-5,ymax=105), linetype="dashed", fill=NA, colour="grey70", size=0.5)+
  geom_rect(aes(xmin=16.5,xmax=17.5,ymin=-5,ymax=105), linetype="dashed", fill=NA, colour="grey70", size=0.5)
# they do stand out a bit, spending almost no time in the shelter, but they do not look particularly different from fish 7, 12, and 21 (also see model diagnostics below)


# model for time in shelter
Shelter_mod2 <- lmer(shelterpercent ~ Treatment * Day + BodyMass_g_calculated + (1|Holding_tank/FishID), data = Shelternew.df2, na.action = na.omit, REML = T)
summary(Shelter_mod2)

# model reduction
Shelter_mod2.2 <- lmer(shelterpercent ~ Treatment + Day + BodyMass_g_calculated + (1|Holding_tank/FishID), data = Shelternew.df2, na.action = na.omit, REML = T)
anova(Shelter_mod2, Shelter_mod2.2)
summary(Shelter_mod2.2)

# model reduction
Shelter_mod2.3 <- lmer(shelterpercent ~ Treatment + Day + (1|Holding_tank/FishID), data = Shelternew.df2, na.action = na.omit, REML = T)
anova(Shelter_mod2.2, Shelter_mod2.3)
summary(Shelter_mod2.3)
# no treatment effect but strong effect of day

# model diagnostics
plot(Shelter_mod2.3)
qqmath(Shelter_mod2.3, id=0.05, idLabels=~FishID)
ggplot(fortify.merMod(Shelter_mod2.3), aes(FishID,.resid)) + geom_boxplot() + coord_flip()
# no indication of fish 6, 15, or 17 being outliers
hist(resid(Shelter_mod2.3))

# predict time spent sheltering for an average-sized (4.2 g) wrasse
predSheltering <- ggpredict(Shelter_mod2.2, terms=c("Day", "Treatment"), condition=c(BodyMass_g_calculated=(mean(Shelternew.df2$BodyMass_g_calculated))))
predSheltering



#####################################################################################################
#FIGURES AND STATS FOR BEHAVIOURAL ARENA TRIALS FOR KRISTINEBERG WRASSE PREDATOR EXPOSURE EXPERIMENT
#####################################################################################################

# NOTES:
# all wrasses were exposed to a predator (cod) in these trials; 'Predator habituated' and 'Predator naive' refer to the previous predator exposure treatment in the holding tank trials, where the same wrasses were kept with (habituated) or without (naive) a cod for 11 days
# Tank 1-4 corresponds to which behavioural arena the wrasses were tested in. Also corresponds to cod 1-4.


# read the data
Wrasse_arenaactivity <- read_delim("Wrasse_behavioural_arena_trials_data.csv", delim=";", locale=locale(decimal_mark = "."), col_types = cols(LatencyFeedSec = col_number(), 
                      LatencyInspectSec = col_number(),
                      Activity = col_number(), bloodwormsconspercent = col_number(), 
                      timean1 = col_number(), timean2 = col_number(), 
                      timean3 = col_number(), timean4 = col_number()))
# inspect data
head(Wrasse_arenaactivity)

# data wrangling
Wrasse_arenaactivity$FishID <- as.factor(as.character(Wrasse_arenaactivity$FishID))
Wrasse_arenaactivity$Tank <- as.factor(as.character(Wrasse_arenaactivity$Tank))
Wrasse_arenaactivity$HoldingTank <- as.factor(as.character(Wrasse_arenaactivity$HoldingTank))
Wrasse_arenaactivity$vid_name <- as.factor(as.character(Wrasse_arenaactivity$vid_name))



### TIME SPENT IN DIFFERENT ZONES OF BEHAVIOURAL ARENA

# reorder tanks
Wrasse_arenaactivity$Tank<-factor(Wrasse_arenaactivity$Tank,levels(Wrasse_arenaactivity$Tank)[c(3,1,2,4)])


# model for time spent in zone 1 (time is sqrt-transformed to achieve normality of model residuals)
Time_mod1 <- lmer(sqrt(timean1) ~ treatment*Food+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
summary(Time_mod1)

# model reduction (non-significant interaction removed)
Time_mod1.2 <- lmer(sqrt(timean1) ~ treatment+Food+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Time_mod1, Time_mod1.2)
summary(Time_mod1.2)

# model reduction
Time_mod1.3 <- lmer(sqrt(timean1) ~ treatment+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Time_mod1.2, Time_mod1.3)
summary(Time_mod1.3)
# no difference between treatments
# NOTE: wrasse body mass (WrasseBodyMass) and time spent by the cod near the wrasse (timeclosetowrasse_cod) were both kept in the model for consistency with the other models (below) analysing time spent by the wrasses in the other zones of the behavioural arena

# model diagnostics
plot(Time_mod1.3)
qqmath(Time_mod1.3, id=0.05)
hist(resid(Time_mod1.3))

# predicted time in zone 1
predZone1 <- ggpredict(Time_mod1.3, terms="treatment", typical="mean")
predZone1$predicted <- (predZone1$predicted)^2
predZone1


# model for time spent in zone 2 (time is sqrt-transformed to achieve normality of model residuals)
Time_mod2 <- lmer(sqrt(timean2) ~ treatment*Food+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
summary(Time_mod2) 

# model reduction (non-significant interaction removed)
Time_mod2.2 <- lmer(sqrt(timean2) ~ treatment+Food+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Time_mod2, Time_mod2.2)
summary(Time_mod2.2) 

# model reduction
Time_mod2.3 <- lmer(sqrt(timean2) ~ treatment+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Time_mod2.2, Time_mod2.3)
summary(Time_mod2.3)
# no difference between treatments

# model diagnostics
plot(Time_mod2.3)
qqmath(Time_mod2.3, id=0.05)
hist(resid(Time_mod2.3))

# predicted time in zone 2
predZone2 <- ggpredict(Time_mod2.3, terms="treatment", typical="mean")
predZone2$predicted <- (predZone2$predicted)^2
predZone2


# model for time spent in zone 3
Time_mod3 <- lmer(timean3 ~ treatment*Food+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
summary(Time_mod3) 

# model reduction (non-significant interaction removed)
Time_mod3.2 <- lmer(timean3 ~ treatment+Food+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Time_mod3, Time_mod3.2)
summary(Time_mod3.2)

# model reduction 
Time_mod3.3 <- lmer(timean3 ~ treatment+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Time_mod3.2, Time_mod3.3)
summary(Time_mod3.3)
# treatment effect; wrasse from predator treatment spend less time in zone 3 (in or near shelter but far from food and far from predator) than no predator treatment

# model diagnostics
plot(Time_mod3.3)
qqmath(Time_mod3.3, id=0.05)
hist(resid(Time_mod3.3))

# predicted time in zone 3
predZone3 <- ggpredict(Time_mod3.3, terms="treatment", typical="mean")
predZone3


# model for time spent in zone 4
Time_mod4 <- lmer(timean4 ~ treatment*Food+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
summary(Time_mod4) 

# model reduction (non-significant interaction removed)
Time_mod4.2 <- lmer(timean4 ~ treatment+Food+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Time_mod4, Time_mod4.2)
summary(Time_mod4.2)

# model reduction
Time_mod4.3 <- lmer(timean4 ~ treatment+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Time_mod4.2, Time_mod4.3)
summary(Time_mod4.3)
# treatment effect; wrasse from predator treatment spend more time in zone 4 (close to cod but away from food) than no predator treatment

# model diagnostics
plot(Time_mod4.3)
qqmath(Time_mod4.3, id=0.05)
hist(resid(Time_mod4.3))

# predicted time in zone 4
predZone4 <- ggpredict(Time_mod4.3, terms="treatment", typical="mean")
predZone4



### SWIMMING ACTIVITY IN BEHAVIOURAL ARENAS

# model for distance moved
Dist_mod1 <- lmer(Activity ~ treatment*Food+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
summary(Dist_mod1) 

# model reduction (non-significant interaction removed)
Dist_mod1.2 <- lmer(Activity ~ treatment+Food+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Dist_mod1, Dist_mod1.2)
summary(Dist_mod1.2) 

# model reduction
Dist_mod1.3 <- lmer(Activity ~ treatment+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Dist_mod1.2, Dist_mod1.3)
summary(Dist_mod1.3)

# model reduction
Dist_mod1.4 <- lmer(Activity ~ treatment+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Dist_mod1.3, Dist_mod1.4)
summary(Dist_mod1.4)

# model reduction
Dist_mod1.5 <- lmer(Activity ~ treatment+(1|Tank), data = Wrasse_arenaactivity, na.action = na.omit, REML = T)
anova(Dist_mod1.4, Dist_mod1.5)
summary(Dist_mod1.5)
# treatment effect; wrasse from predator treatment are more active than no predator treatment

# model diagnostics
plot(Dist_mod1.5)
qqmath(Dist_mod1.5, id=0.05)
hist(resid(Dist_mod1.5))

# predicted distance moved
predDist <- ggpredict(Dist_mod1.5, terms="treatment", typical="mean")
predDist


# Plot of total distance moved
# data wrangling to average behaviours occurring before and after food addition to arena
Wrasse_arenaactivity2 <- Wrasse_arenaactivity[,-which(names(Wrasse_arenaactivity) %in% "Food")]

Wrasse_arenaactivity2 <- Wrasse_arenaactivity2 %>% group_by(FishID, HoldingTank, vid_name, Tank, treatment) %>% summarise_all(.funs = c(mean="mean"), na.rm = TRUE)

# change treatment order for plotting
Wrasse_arenaactivity2$treatment <- factor(Wrasse_arenaactivity2$treatment, levels=c("Predator habituated","Predator naive"))

ggplot(Wrasse_arenaactivity2, aes(x=treatment, y=Activity_mean, colour=treatment, shape=treatment, fill=treatment))+
  scale_color_manual(values=c("coral3", "dodgerblue4"))+
  scale_fill_manual(values=c("coral3", "dodgerblue4"))+
  scale_shape_manual(values=c(18,16))+
  stat_summary(fun=mean, geom="point", aes(group=treatment), size=5)+
  stat_summary(fun.data = mean_se, geom = "errorbar", width=0.1)+
  geom_point(position=position_jitterdodge(jitter.width=0.3), size=3, alpha=0.4)+
  geom_smooth(method="lm", alpha=0.2)+
  theme_bw()+
  theme(plot.background = element_blank(),
        panel.background = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank())+
  theme(panel.border = element_rect(color="black", size = 0.3))+
  theme(axis.line.x = element_blank(),
        axis.line.y = element_blank())+
  theme(axis.ticks.length=unit(2,"mm"), axis.ticks.y = element_line(colour = "black", size = 0.3), axis.ticks.x = element_line(colour = "black", size = 0.3))+
  theme(aspect.ratio=1/1)+
  theme(text = element_text(size=18, colour="black"),
        axis.text.y = element_text(size=18, colour="black"), 
        axis.text.x = element_text(size=18, colour="black"))+
  theme(legend.position = "none")+
  scale_y_continuous(breaks=seq(0,400,100))+
  coord_cartesian(ylim=c(0,400))+
  labs(y=expression(Swimming ~ activity ~ (cm ~ min^-1)), x=expression(Treatment))

# reset treatment order
Wrasse_arenaactivity2$treatment <- factor(Wrasse_arenaactivity2$treatment, levels=c("Predator naive","Predator habituated"))



### LATENCY TO INSPECT FOOD AND TO FEED IN BEHAVIOURAL ARENAS

# subset data frame for behaviours occurring only after feeding
Wrasse_arenaactivity_fed <- subset(Wrasse_arenaactivity, Food == "After")

# add columns to data frame with yes (1) or no (0) for whether or not the fish inspected or ate the food or not
Wrasse_arenaactivity_fed$Inspect <- ifelse(Wrasse_arenaactivity_fed$LatencyInspectSec == 1872, 0, ifelse(Wrasse_arenaactivity_fed$LatencyInspectSec == 1914, 0, 1))

Wrasse_arenaactivity_fed$Feed <- ifelse(Wrasse_arenaactivity_fed$LatencyFeedSec == 1872, 0, ifelse(Wrasse_arenaactivity_fed$LatencyFeedSec == 1914, 0, 1))

# add new columns with latencies in min rather than s
Wrasse_arenaactivity_fed$LatencyInspectMin <- Wrasse_arenaactivity_fed$LatencyInspectSec/60

Wrasse_arenaactivity_fed$LatencyFeedMin <- Wrasse_arenaactivity_fed$LatencyFeedSec/60


# model for latency to inspect food
LatencyInspect_mod1 <- coxme(Surv(LatencyInspectMin, Inspect) ~ treatment + timeclosetowrasse_cod + WrasseBodyMass_g + (1|Tank), data=Wrasse_arenaactivity_fed)
summary(LatencyInspect_mod1)

# model reduction
LatencyInspect_mod1.2 <- coxme(Surv(LatencyInspectMin, Inspect) ~ treatment + WrasseBodyMass_g + (1|Tank), data=Wrasse_arenaactivity_fed)
anova(LatencyInspect_mod1, LatencyInspect_mod1.2)
summary(LatencyInspect_mod1.2)
# no treatment effect
# NOTE: wrasse body mass is kept in the model for consistency with model for latency to feed, where body mass has a significant effect


# plot of latency to inspect food
LatencyInspect_fit <- survfit(Surv(LatencyInspectMin, Inspect) ~ treatment, data=Wrasse_arenaactivity_fed)

ggsurvplot(LatencyInspect_fit, data=Wrasse_arenaactivity_fed, fun = "event",
           conf.int = TRUE, 
           legend.labs = c("Predator habituated", "Predator naive"), 
           legend.title = "Treatment",
           legend = c(0.82, 0.1),
           xlab = "Time (min)", ylab="Proportion having inspected food", xlim=c(0,32), break.x.by = 5, break.y.by = 0.2, censor.shape = 4, censor.size = 3, palette = c("coral3", "dodgerblue4"), conf.int.alpha = 0.2,
  ggtheme = theme_bw()+
  theme(plot.background = element_blank(),
        panel.background = element_blank(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank())+
  theme(panel.border = element_rect(color="black", size = 0.3))+
  theme(axis.line.x = element_blank(),
        axis.line.y = element_blank())+
  theme(axis.ticks.length=unit(2,"mm"), axis.ticks.y = element_line(colour = "black", size = 0.3), axis.ticks.x = element_line(colour = "black", size = 0.3))+
  theme(aspect.ratio=1/1))


# model for latency to feed
LatencyFeed_mod1 <- coxme(Surv(LatencyFeedMin, Feed) ~ treatment + timeclosetowrasse_cod + WrasseBodyMass_g + (1|Tank), data=Wrasse_arenaactivity_fed)
summary(LatencyFeed_mod1)

# model reduction
LatencyFeed_mod1.2 <- coxme(Surv(LatencyFeedMin, Feed) ~ treatment + WrasseBodyMass_g + (1|Tank), data=Wrasse_arenaactivity_fed)
anova(LatencyFeed_mod1, LatencyFeed_mod1.2)
summary(LatencyFeed_mod1.2)
# no treatment effect


# plot of latency to feed
LatencyFeed_fit <- survfit(Surv(LatencyFeedMin, Feed) ~ treatment, data=Wrasse_arenaactivity_fed)

ggsurvplot(LatencyFeed_fit, data=Wrasse_arenaactivity_fed, fun = "event",
           conf.int = TRUE, 
           legend.labs = c("Predator habituated", "Predator naive"), 
           legend.title = "Treatment",
           legend = c(0.82, 0.1),
           xlab = "Time (min)", ylab="Proportion having eaten food", xlim=c(0,32), break.x.by = 5, break.y.by = 0.2, censor.shape = 4, censor.size = 3, palette = c("coral3", "dodgerblue4"), conf.int.alpha = 0.2,
           ggtheme = theme_bw()+
             theme(plot.background = element_blank(),
                   panel.background = element_blank(),
                   panel.grid.major = element_blank(),
                   panel.grid.minor = element_blank())+
             theme(panel.border = element_rect(color="black", size = 0.3))+
             theme(axis.line.x = element_blank(),
                   axis.line.y = element_blank())+
             theme(axis.ticks.length=unit(2,"mm"), axis.ticks.y = element_line(colour = "black", size = 0.3), axis.ticks.x = element_line(colour = "black", size = 0.3))+
             theme(aspect.ratio=1/1))



### FOOD CONSUMPTION IN BEHAVIOURAL ARENAS

# data wrangling
Wrasse_arenaactivity_fed$Tank<-factor(Wrasse_arenaactivity_fed$Tank,levels(Wrasse_arenaactivity_fed$Tank)[c(3,1,2,4)])
levels(Wrasse_arenaactivity_fed$Tank)
Wrasse_arenaactivity_fed$treatment <- as.factor(Wrasse_arenaactivity_fed$treatment)
levels(Wrasse_arenaactivity_fed$treatment)

# calculate food consumption as percent of body mass (rather than percent of the 40 bloodworms fed in total)
Wrasse_arenaactivity_fed$bloodwormscons_percentBM <- (((Wrasse_arenaactivity_fed$bloodwormsconspercent/100)*40*(7.144/1000))/Wrasse_arenaactivity_fed$WrasseBodyMass_g)*100


# model for food consumption
Consumption_mod1 <- lmer(bloodwormscons_percentBM ~ treatment+timeclosetowrasse_cod+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity_fed, REML = T)
summary(Consumption_mod1)

# model reduction
Consumption_mod2 <- lmer(bloodwormscons_percentBM ~ treatment+WrasseBodyMass_g+(1|Tank), data = Wrasse_arenaactivity_fed, REML = T)
anova(Consumption_mod1, Consumption_mod2)
summary(Consumption_mod2)

# model reduction
Consumption_mod3 <- lmer(bloodwormscons_percentBM ~ treatment+(1|Tank), data = Wrasse_arenaactivity_fed, REML = T)
anova(Consumption_mod2, Consumption_mod3)
summary(Consumption_mod3)
# no treatment effect

# model diagnostics
plot(Consumption_mod3)
qqmath(Consumption_mod3, id=0.05)
hist(resid(Consumption_mod3))

# predicted amount of worms (percent of body mass) eaten for an average-sized (4.2 g) fish
predConsumptionBehavTrial_percentBM <- ggpredict(Consumption_mod2, terms="treatment", condition=c(WrasseBodyMass_g=(mean(Wrasse_arenaactivity_fed$WrasseBodyMass_g))))
predConsumptionBehavTrial_percentBM

# Mean percentage of aerobic scope occupied by eaten food
# Predator habituated
coef(summary(mod.PeakSDA.predict))[1] + predConsumptionBehavTrial_percentBM[1,2]*coef(summary(mod.PeakSDA.predict))[2]

# Predator naive
coef(summary(mod.PeakSDA.predict))[1] + predConsumptionBehavTrial_percentBM[2,2]*coef(summary(mod.PeakSDA.predict))[2]
